@@ -1,4 +1,4 @@
-// SPDX-License-Identifier: GPL-2.0-only
+// SPDX-License-Identifier: GPL-2.0-or-later
 /* Copyright (c) 2022 Meta Platforms, Inc.
  *
  * Authors: Arthur Shau <arthurshau@fb.com>,
@@ -380,11 +380,6 @@ static int get_c0_log_page(int fd, char *format)
                 }
 
                 /* print the data */
-                if (!data) {
-                        fprintf(stderr, "ERROR : OCP : Invalid buffer to read 0xC0 log\n");
-                        ret = -1;
-                        goto out;
-                }
                 switch (fmt) {
                 case NORMAL:
                         ocp_print_C0_log_normal(data);
@@ -430,11 +425,11 @@ static int ocp_smart_add_log(int argc, char **argv, struct command *cmd,
         if (ret)
                 fprintf(stderr, "ERROR : OCP : Failure reading the C0 Log Page, ret = %d\n",
                         ret);
-
+        close(fd);
         return ret;
 }
 
-static int ocp_print_C3_log_normal(int fd, struct ssd_latency_monitor_log *log_data)
+static int ocp_print_C3_log_normal(struct ssd_latency_monitor_log *log_data)
 {
         printf("-Latency Monitor/C3 Log Page Data- \n");
         printf("  Controller   :  %s\n", devicename);
@@ -728,16 +723,9 @@ static int get_c3_log_page(int fd, char *format)
                         }
                 }
 
-                /* print the data */
-                if (!log_data) {
-                        fprintf(stderr,
-                                "ERROR : OCP : Invalid C3 log data buffer\n");
-                        ret = -1;
-                        goto out;
-                }
                 switch (fmt) {
                 case NORMAL:
-                        ocp_print_C3_log_normal(fd, log_data);
+                        ocp_print_C3_log_normal(log_data);
                         break;
                 case JSON:
                         ocp_print_C3_log_json(log_data);
@@ -783,6 +771,6 @@ static int ocp_latency_monitor_log(int argc, char **argv, struct command *comman
                 fprintf(stderr,
                         "ERROR : OCP : Failure reading the C3 Log Page, ret = %d\n",
                         ret);
-
+        close(fd);
         return ret;
 }
